Description: ${ entry.description }
Keywords: ${ ', '.join(entry.tags) }

<%inherit file="base.html" /> <%namespace file="entry.html" import="block_entry" /> <%block name="title"> % if entry: ${ entry.title } % else: ${ conf.sitename } % endif <%block name="head"> ${ parent.head() } % if entry: % endif <%block name="content"> % for entry in env.entrylist: ${block_entry(entry)} % endfor % if env.prev is not None: ${ env.prev.title } » % endif % if env.next is not None: « ${ env.next.title } % endif <%block name="footer"> ${ parent.footer() } % if 'disqus_shortname' in conf and env.type == 'index':
% endif